@@ -395,22 +395,10 @@ cbuf2_insert_chunk (RIP_MANAGER_INFO* rmi,
 	list_splice (&this_page_list, cbuf2->ogg_page_list.prev);
     } else if (ti && ti->have_track_info) {
 	/* Insert metadata data */
-#if defined (commentout)
-	int num_bytes;
-	unsigned char num_16_bytes;
-#endif
 	METADATA_LIST* ml;
 	ml = (METADATA_LIST*) malloc (sizeof(METADATA_LIST));
 	/* GCS FIX: Check malloc error */
 	ml->m_chunk = chunk_no;
-#if defined (commentout)
-	num_bytes = snprintf (&ml->m_composed_metadata[1], MAX_METADATA_LEN,
-			      "StreamTitle='%s - %s';", 
-			      ti->artist, ti->title);
-	ml->m_composed_metadata[MAX_METADATA_LEN] = 0;  // note, not LEN-1
-	num_16_bytes = (num_bytes + 15) / 16;
-	ml->m_composed_metadata[0] = num_16_bytes;
-#endif
 	memcpy (ml->m_composed_metadata, ti->composed_metadata, 
 		MAX_METADATA_LEN+1);
 	list_add_tail (&(ml->m_list), &(cbuf2->metadata_list));
