@@ -22,8 +22,6 @@
 #include "list.h"
 #include "relaylib.h"
 
-#define MAX_METADATA_LEN (127*16)
-
 /* Each metadata within the cbuf gets this struct */
 typedef struct METADATA_LIST_struct METADATA_LIST;
 struct METADATA_LIST_struct
@@ -38,39 +36,6 @@ struct METADATA_LIST_struct
 #define OGG_PAGE_EOS        0x02
 #define OGG_PAGE_2          0x04
 
-/* Each ogg page boundary within the cbuf gets this struct */
-typedef struct OGG_PAGE_LIST_struct OGG_PAGE_LIST;
-struct OGG_PAGE_LIST_struct
-{
-    unsigned long m_page_start;
-    unsigned long m_page_len;
-    unsigned long m_page_flags;
-    unsigned char *m_header_buf_ptr;
-    unsigned long m_header_buf_len;
-    LIST m_list;
-};
-
-typedef struct CBUF2_struct
-{
-    char*	buf;
-    int         content_type;
-    int         have_relay;
-    u_long	num_chunks;
-    u_long	chunk_size;
-    u_long	size;        /* size is chunk_size * num_chunks */
-    u_long	base_idx;
-    u_long	item_count;  /* Amount filled */
-    u_long	next_song;   /* start of next song (mp3 only) */
-    OGG_PAGE_LIST* song_page;    /* current page being written (ogg only) */
-    u_long      song_page_done;  /* amount finished in current page (ogg) */
-
-    HSEM        cbuf_sem;
-
-    LIST        metadata_list;
-    LIST        ogg_page_list;
-    LIST        frame_list;
-} CBUF2;
-
 
 /*****************************************************************************
  * Global variables
@@ -85,10 +50,11 @@ error_code
 cbuf2_init (CBUF2 *cbuf2, int content_type, int have_relay, 
 	    unsigned long chunk_size, unsigned long num_chunks);
 void cbuf2_destroy(CBUF2 *buffer);
-error_code cbuf2_extract (CBUF2 *cbuf2, char *data, 
+error_code cbuf2_extract (RIP_MANAGER_INFO* rmi, CBUF2 *cbuf2, char *data, 
 			  u_long count, u_long* curr_song);
 error_code cbuf2_peek(CBUF2 *buffer, char *items, u_long count);
-error_code cbuf2_insert_chunk (CBUF2 *cbuf2, const char *data, u_long count,
+error_code cbuf2_insert_chunk (RIP_MANAGER_INFO* rmi, 
+			       CBUF2 *cbuf2, const char *data, u_long count,
 			       int content_type, TRACK_INFO* ti);
 error_code cbuf2_fastforward (CBUF2 *buffer, u_long count);
 error_code cbuf2_peek_rgn (CBUF2 *buffer, char *out_buf, 
@@ -114,7 +80,6 @@ error_code cbuf2_extract_relay (CBUF2 *cbuf2, char *data, u_long *pos,
 				u_long *len, int icy_metadata);
 #endif
 error_code cbuf2_extract_relay (CBUF2 *cbuf2, RELAY_LIST* ptr);
-error_code cbuf2_advance_ogg (CBUF2 *cbuf2, int requested_free_size);
-void cbuf2_debug_lists (CBUF2 *cbuf2);
+error_code cbuf2_advance_ogg (RIP_MANAGER_INFO* rmi, CBUF2 *cbuf2, int requested_free_size);
 
 #endif
