@@ -17,12 +17,17 @@
 #ifndef __DEBUG_H__
 #define __DEBUG_H__
 
+#include "srtypes.h"
 #include "time.h"
 #include <stdio.h>
+
+#define debug_mprintf debug_printf
+
 void debug_open (void);
 void debug_set_filename (char* filename);
 void debug_close (void);
 void debug_printf (char* fmt, ...);
+//void debug_mprintf (mchar* fmt, ...);
 void debug_enable (void);
 void debug_print_error (void);
 
