@@ -19,29 +19,8 @@
 
 #include "srtypes.h"
 
-#define MAX_EXT_LINE_LEN 255
-
-typedef struct external_process External_Process;
-struct external_process
-{
-#if defined (WIN32)
-    HANDLE mypipe;   /* read from child stdout */
-    HANDLE hproc;
-    DWORD pid;
-#else
-    int mypipe[2];   /* 0 is for parent reading, 1 is for parent writing */
-    pid_t pid;
-#endif
-    int line_buf_idx;
-    char line_buf[MAX_EXT_LINE_LEN];
-    char album_buf[MAX_EXT_LINE_LEN];
-    char artist_buf[MAX_EXT_LINE_LEN];
-    char title_buf[MAX_EXT_LINE_LEN];
-    char metadata_buf[MAX_EXT_LINE_LEN];
-};
-
 External_Process* spawn_external (char* cmd);
-int read_external (External_Process* ep, TRACK_INFO* ti);
+int read_external (RIP_MANAGER_INFO* rmi, External_Process* ep, TRACK_INFO* ti);
 void close_external (External_Process** epp);
 
 #endif
