@@ -81,6 +81,7 @@ static void fill_date_buf (RIP_MANAGER_INFO* rmi, gchar* datebuf,
 static error_code filelib_open_showfiles (RIP_MANAGER_INFO* rmi);
 static void move_file (RIP_MANAGER_INFO* rmi, gchar* new_filename, gchar* old_filename);
 static gchar* replace_invalid_chars (gchar *str);
+static void remove_trailing_periods (gchar *str);
 static BOOL new_file_is_better (RIP_MANAGER_INFO* rmi, gchar *oldfile, gchar *newfile);
 static void delete_file (RIP_MANAGER_INFO* rmi, gchar* filename);
 static void truncate_file (RIP_MANAGER_INFO* rmi, gchar* filename);
@@ -131,16 +132,16 @@ filelib_init (RIP_MANAGER_INFO* rmi,
 		  showfile_pattern ? showfile_pattern : "");
     
     debug_printf ("converting output_directory\n");
-    mstring_from_string (rmi, tmp_output_directory, SR_MAX_PATH, 
+    gstring_from_string (rmi, tmp_output_directory, SR_MAX_PATH, 
 			 output_directory, CODESET_LOCALE);
     debug_printf ("converting output_pattern\n");
-    mstring_from_string (rmi, tmp_output_pattern, SR_MAX_PATH, 
+    gstring_from_string (rmi, tmp_output_pattern, SR_MAX_PATH, 
 			 output_pattern, CODESET_LOCALE);
     debug_printf ("converting showfile_pattern\n");
-    mstring_from_string (rmi, tmp_showfile_pattern, SR_MAX_PATH, 
+    gstring_from_string (rmi, tmp_showfile_pattern, SR_MAX_PATH, 
 			 showfile_pattern, CODESET_LOCALE);
     debug_printf ("converting icy_name\n");
-    mstring_from_string (rmi, fli->m_icy_name, SR_MAX_PATH, icy_name, 
+    gstring_from_string (rmi, fli->m_icy_name, SR_MAX_PATH, icy_name, 
 			 CODESET_METADATA);
     debug_printf ("Converted output directory: len=%d\n", 
 		  mstrlen (tmp_output_directory));
@@ -148,6 +149,11 @@ filelib_init (RIP_MANAGER_INFO* rmi,
     
     debug_printf ("Replacing invalid chars in stripped_icy_name\n");
     replace_invalid_chars (fli->m_stripped_icy_name);
+    debug_printf ("  %s\n", fli->m_stripped_icy_name);
+
+    debug_printf ("Removing trailing periods\n");
+    remove_trailing_periods (fli->m_stripped_icy_name);
+    debug_printf ("  %s\n", fli->m_stripped_icy_name);
 
     switch (content_type) {
     case CONTENT_TYPE_MP3:
@@ -278,10 +284,10 @@ filelib_write_cue (RIP_MANAGER_INFO* rmi, TRACK_INFO* ti, int secs)
     rc = snprintf (buf2, MAX_TRACK_LEN, "  TRACK %02d AUDIO\n", 
 		   fli->m_track_no++);
     filelib_write (fli->m_cue_file, buf2, rc);
-    string_from_mstring (rmi, buf1, MAX_TRACK_LEN, ti->title, CODESET_ID3);
+    string_from_gstring (rmi, buf1, MAX_TRACK_LEN, ti->title, CODESET_ID3);
     rc = snprintf (buf2, MAX_TRACK_LEN, "    TITLE \"%s\"\n", buf1);
     filelib_write (fli->m_cue_file, buf2, rc);
-    string_from_mstring (rmi, buf1, MAX_TRACK_LEN, ti->artist, CODESET_ID3);
+    string_from_gstring (rmi, buf1, MAX_TRACK_LEN, ti->artist, CODESET_ID3);
     rc = snprintf (buf2, MAX_TRACK_LEN, "    PERFORMER \"%s\"\n", buf1);
     filelib_write (fli->m_cue_file, buf2, rc);
     rc = snprintf (buf2, MAX_TRACK_LEN, "    INDEX 01 %02d:%02d:00\n", 
@@ -303,9 +309,11 @@ filelib_write_show (RIP_MANAGER_INFO* rmi, char *buf, u_long size)
 {
     FILELIB_INFO* fli = &rmi->filelib_info;
     error_code rc;
+    debug_printf ("Testing to write showfile\n");
     if (!fli->m_do_show) {
 	return SR_SUCCESS;
     }
+    debug_printf ("Trying to write showfile\n");
     rc = filelib_write (fli->m_show_file, buf, size);
     if (rc != SR_SUCCESS) {
 	fli->m_do_show = 0;
@@ -403,7 +411,7 @@ static error_code
 mkdir_if_needed (RIP_MANAGER_INFO* rmi, gchar *str)
 {
     char s[SR_MAX_PATH];
-    string_from_mstring (rmi, s, SR_MAX_PATH, str, CODESET_FILESYS);
+    string_from_gstring (rmi, s, SR_MAX_PATH, str, CODESET_FILESYS);
     debug_printf ("mkdir = %s -> %s\n", str, s);
 #if WIN32
     mkdir (s);
@@ -675,7 +683,7 @@ fill_date_buf (RIP_MANAGER_INFO* rmi, gchar* datebuf, int datebuf_len)
     char tmp[DATEBUF_LEN];
     time_t now = time(NULL);
     strftime (tmp, datebuf_len, "%Y_%m_%d_%H_%M_%S", localtime(&now));
-    mstring_from_string (rmi, datebuf, DATEBUF_LEN, tmp, CODESET_FILESYS);
+    gstring_from_string (rmi, datebuf, DATEBUF_LEN, tmp, CODESET_FILESYS);
 }
 
 static error_code
@@ -726,7 +734,7 @@ sr_getcwd (RIP_MANAGER_INFO* rmi, gchar* dirbuf)
 	return SR_ERROR_DIR_PATH_TOO_LONG;
     }
 #endif
-    mstring_from_string (rmi, dirbuf, SR_MAX_PATH, db, CODESET_FILESYS);
+    gstring_from_string (rmi, dirbuf, SR_MAX_PATH, db, CODESET_FILESYS);
     return SR_SUCCESS;
 }
 
@@ -757,7 +765,7 @@ file_exists (RIP_MANAGER_INFO* rmi, gchar *filename)
 {
     FHANDLE f;
     char fn[SR_MAX_PATH];
-    string_from_mstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
+    string_from_gstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
 #if defined (WIN32)
     f = CreateFile (fn, GENERIC_READ,
 	    FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING,
@@ -837,7 +845,7 @@ parse_and_subst_pat (RIP_MANAGER_INFO* rmi,
 	case m_('S'):
 	    /* stream name */
 	    /* GCS FIX: Not sure here */
-	    mstrncat (newfile, fli->m_icy_name, MAX_FILEBASELEN-nfi);
+	    mstrncat (newfile, fli->m_stripped_icy_name, MAX_FILEBASELEN-nfi);
 	    nfi = mstrlen (newfile);
 	    opi+=2;
 	    continue;
@@ -935,7 +943,7 @@ get_file_size (RIP_MANAGER_INFO* rmi, gchar *filename)
     long len;
     char fn[SR_MAX_PATH];
 
-    string_from_mstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
+    string_from_gstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
     fp = fopen (fn, "r");
     if (!fp) return 0;
 
@@ -1004,7 +1012,7 @@ static void
 truncate_file (RIP_MANAGER_INFO* rmi, gchar* filename)
 {
     char fn[SR_MAX_PATH];
-    string_from_mstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
+    string_from_gstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
     debug_printf ("Trying to truncate file: %s\n", fn);
 #if defined WIN32
     CloseHandle (CreateFile(fn, GENERIC_WRITE, 
@@ -1022,8 +1030,8 @@ move_file (RIP_MANAGER_INFO* rmi, gchar* new_filename, gchar* old_filename)
 {
     char old_fn[SR_MAX_PATH];
     char new_fn[SR_MAX_PATH];
-    string_from_mstring (rmi, old_fn, SR_MAX_PATH, old_filename, CODESET_FILESYS);
-    string_from_mstring (rmi, new_fn, SR_MAX_PATH, new_filename, CODESET_FILESYS);
+    string_from_gstring (rmi, old_fn, SR_MAX_PATH, old_filename, CODESET_FILESYS);
+    string_from_gstring (rmi, new_fn, SR_MAX_PATH, new_filename, CODESET_FILESYS);
 #if defined WIN32
     MoveFile(old_fn, new_fn);
 #else
@@ -1035,7 +1043,7 @@ static void
 delete_file (RIP_MANAGER_INFO* rmi, gchar* filename)
 {
     char fn[SR_MAX_PATH];
-    string_from_mstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
+    string_from_gstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
 #if defined WIN32
     DeleteFile (fn);
 #else
@@ -1047,7 +1055,7 @@ static error_code
 filelib_open_for_write (RIP_MANAGER_INFO* rmi, FHANDLE* fp, gchar* filename)
 {
     char fn[SR_MAX_PATH];
-    string_from_mstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
+    string_from_gstring (rmi, fn, SR_MAX_PATH, filename, CODESET_FILESYS);
     debug_printf ("Trying to create file: %s\n", fn);
 #if WIN32
     *fp = CreateFile (fn, GENERIC_WRITE,         // open for reading 
@@ -1200,7 +1208,7 @@ filelib_adjust_cuefile (RIP_MANAGER_INFO* rmi, gchar* new_show_name,
     rc = msnprintf (mcue_buf, 1024, m_("FILE \"") m_S m_("\" MP3\n"), 
 		    show_fnbase);
     g_free (show_fnbase);
-    rc = string_from_mstring (rmi, cue_buf, 1024, mcue_buf, CODESET_FILESYS);
+    rc = string_from_gstring (rmi, cue_buf, 1024, mcue_buf, CODESET_FILESYS);
     fwrite (cue_buf, 1, rc, fp_out);
 
     /* Skip line in input file */
@@ -1261,32 +1269,36 @@ filelib_open_showfiles (RIP_MANAGER_INFO* rmi)
     g_free (new_dir);
     g_free (new_fnbase);
 
-    /* Open cue file */
-    rc = filelib_open_for_write (rmi, &fli->m_cue_file, fli->m_cue_name);
-    if (rc != SR_SUCCESS) {
-	fli->m_do_show = 0;
-	return rc;
+    /* Open cue file, write header */
+    if (rmi->http_info.content_type != CONTENT_TYPE_OGG) {
+	rc = filelib_open_for_write (rmi, &fli->m_cue_file, fli->m_cue_name);
+	if (rc != SR_SUCCESS) {
+	    fli->m_do_show = 0;
+	    return rc;
+	}
+
+	/* Write cue header here */
+	/* GCS Nov 29, 2007 - As suggested on the forum, the cue file
+	   should use relative path. */
+	basename = mstrrchr (fli->m_show_name, PATH_SLASH);
+	if (basename) {
+	    basename++;
+	} else {
+	    basename = fli->m_show_name;
+	}
+	debug_mprintf (m_("show_name: ") m_S m_(", basename: ") m_S m_("\n"),
+		       fli->m_show_name, basename);
+	rc = msnprintf (mcue_buf, 1024, m_("FILE \"") m_S m_("\" MP3\n"), 
+			basename);
+	rc = string_from_gstring (rmi, cue_buf, 1024, mcue_buf, CODESET_FILESYS);
+	rc = filelib_write (fli->m_cue_file, cue_buf, rc);
+	if (rc != SR_SUCCESS) {
+	    fli->m_do_show = 0;
+	    return rc;
+	}
     }
 
-    /* Write cue header here */
-    /* GCS Nov 29, 2007 - As suggested on the forum, the cue file
-       should use relative path. */
-    basename = mstrrchr (fli->m_show_name, PATH_SLASH);
-    if (basename) {
-	basename++;
-    } else {
-	basename = fli->m_show_name;
-    }
-    debug_mprintf (m_("show_name: ") m_S m_(", basename: ") m_S m_("\n"),
-		   fli->m_show_name, basename);
-    rc = msnprintf (mcue_buf, 1024, m_("FILE \"") m_S m_("\" MP3\n"), 
-		    basename);
-    rc = string_from_mstring (rmi, cue_buf, 1024, mcue_buf, CODESET_FILESYS);
-    rc = filelib_write (fli->m_cue_file, cue_buf, rc);
-    if (rc != SR_SUCCESS) {
-	fli->m_do_show = 0;
-	return rc;
-    }
+    /* Open show file */
     rc = filelib_open_for_write (rmi, &fli->m_show_file, fli->m_show_name);
     if (rc != SR_SUCCESS) {
 	fli->m_do_show = 0;
@@ -1348,8 +1360,8 @@ get_next_sequence_number (RIP_MANAGER_INFO* rmi, gchar* fn_base)
     fn_prefix[0] = 0;
     mstrcpy (fn_prefix, &fn_base[edi+1]);
 
-    rc = string_from_mstring (rmi, dname, SR_MAX_PATH, dir_name, CODESET_FILESYS);
-    rc = string_from_mstring (rmi, fnp, SR_MAX_PATH, fn_prefix, CODESET_FILESYS);
+    rc = string_from_gstring (rmi, dname, SR_MAX_PATH, dir_name, CODESET_FILESYS);
+    rc = string_from_gstring (rmi, fnp, SR_MAX_PATH, fn_prefix, CODESET_FILESYS);
 
     /* Look through directory for a filenames that match prefix */
     if ((dp = opendir (dname)) == 0) {
@@ -1370,15 +1382,10 @@ get_next_sequence_number (RIP_MANAGER_INFO* rmi, gchar* fn_base)
     return seq;
 }
 
-/* GCS FIX: This should only strip "." at beginning of path */
 static gchar* 
 replace_invalid_chars (gchar *str)
 {
-# if defined (WIN32)
     gchar invalid_chars[] = m_("\\/:*?\"<>|~");
-# else
-    gchar invalid_chars[] = m_("\\/:*?\"<>|.~");
-# endif
     gchar replacement = m_('-');
 
     gchar *oldstr = str;
@@ -1386,10 +1393,23 @@ replace_invalid_chars (gchar *str)
 
     if (!str) return NULL;
 
+    /* Skip leading "." */
     for (;*oldstr; oldstr++) {
-	if (mstrchr(invalid_chars, *oldstr) == NULL) {
+	if (*oldstr != '.') {
+	    break;
+	}
+    }
+
+    for (;*oldstr; oldstr++) {
+	if (g_ascii_iscntrl (*oldstr)) {
+	    /* Do nothing -- skip control characters without replacement */
+	}
+	else if (mstrchr(invalid_chars, *oldstr) == NULL) {
+	    /* Ordinary case -- copy */
 	    *newstr++ = *oldstr;
-	} else {
+	}
+	else {
+	    /* Replace case -- append replacement char */
 	    *newstr++ = replacement;
 	}
     }
@@ -1397,3 +1417,12 @@ replace_invalid_chars (gchar *str)
 
     return str;
 }
+
+static void
+remove_trailing_periods (gchar *str)
+{
+    gchar* s = str + strlen (str);
+    while (--s >= str && *s == '.') {
+	*s = 0;
+    }
+}
