@@ -19,9 +19,10 @@
 #define __FINDSEP_H__
 
 #include "srtypes.h"
+#include "errors.h"
 
 error_code
-findsep_silence (const u_char* mpgbuf, 
+findsep_silence (const char* mpgbuf, 
 		 long mpgsize, 
 		 long len_to_sw,
 		 long searchwindow,
@@ -31,7 +32,18 @@ findsep_silence (const u_char* mpgbuf,
 		 u_long* pos1, 
 		 u_long* pos2
 		 );
-error_code find_bitrate(unsigned long* bitrate, const u_char* mpgbuf, 
-			long mpgsize);
+error_code
+findsep_silence_2 (const char* mpgbuf, 
+		 long mpgsize, 
+		 long len_to_sw,
+		 long searchwindow,
+		 long silence_length, 
+		 long padding1,
+		 long padding2,
+		 u_long* pos1, 
+		 u_long* pos2
+		 );
+error_code
+find_bitrate (unsigned long* bitrate, const char* mpgbuf, long mpgsize);
 
 #endif //__FINDSEP_H__
