@@ -64,10 +64,11 @@ http_sc_connect (RIP_MANAGER_INFO* rmi,
 	debug_printf ("***** URL = %s *****\n", url);
 	debug_printf("http_sc_connect(): calling http_parse_url\n");
 	if (proxyurl) {
-	    if ((ret = http_parse_url(proxyurl, &url_info)) != SR_SUCCESS) {
+	    debug_printf ("***** PROXY = %s *****\n", proxyurl);
+	    if ((ret = http_parse_url (proxyurl, &url_info)) != SR_SUCCESS) {
 		return ret;
 	    }
-	} else if ((ret = http_parse_url(url, &url_info)) != SR_SUCCESS) {
+	} else if ((ret = http_parse_url (url, &url_info)) != SR_SUCCESS) {
 	    return ret;
 	}
 
@@ -75,18 +76,25 @@ http_sc_connect (RIP_MANAGER_INFO* rmi,
 	if ((ret = socklib_init()) != SR_SUCCESS)
 	    return ret;
 
-	debug_printf("http_sc_connect(): calling socklib_open: host=%s, port=%d\n",
-	    url_info.host, url_info.port);
-	if ((ret = socklib_open(sock, url_info.host, url_info.port, if_name)) != SR_SUCCESS)
+	debug_printf ("http_sc_connect(): calling socklib_open"
+		      " host=%s, port=%d\n", url_info.host, url_info.port);
+	ret = socklib_open (sock, url_info.host, url_info.port, if_name, 
+			    rmi->prefs->timeout);
+	if (ret != SR_SUCCESS) {
 	    return ret;
+	}
 
 	debug_printf("http_sc_connect(): calling http_construct_sc_request\n");
-	if ((ret = http_construct_sc_request(url, proxyurl, headbuf, useragent)) != SR_SUCCESS)
+	ret = http_construct_sc_request (url, proxyurl, headbuf, useragent);
+	if (ret != SR_SUCCESS) {
 	    return ret;
+	}
 
 	debug_printf("http_sc_connect(): calling socklib_sendall\n");
-	if ((ret = socklib_sendall(sock, headbuf, strlen(headbuf))) < 0)
+	ret = socklib_sendall (sock, headbuf, strlen(headbuf));
+	if (ret < 0) {
 	    return ret;
+	}
 
 	debug_printf("http_sc_connect(): calling http_get_sc_header\n");
 	if ((ret = http_get_sc_header(rmi, url, sock, info)) != SR_SUCCESS)
@@ -140,6 +148,9 @@ http_parse_url(const char *url, URLINFO *urlinfo)
     int ret;
     char *s;
 
+
+    debug_printf ("http_parse_url: %s\n", url);
+
     /* if we have a proto, just skip it. should we care about 
        the proto? like fail if it's not http? */
     s = strstr(url, "://");
@@ -700,10 +711,9 @@ http_get_pls (RIP_MANAGER_INFO* rmi, HSOCKET *sock, SR_HTTP_HEADER *info)
     char buf[MAX_PLS_LEN];
     char location_buf[MAX_PLS_LEN];
     char title_buf[MAX_PLS_LEN];
-    const int timeout = 30;
 
     debug_printf ("Reading pls\n");
-    bytes = socklib_recvall (rmi, sock, buf, MAX_PLS_LEN, timeout);
+    bytes = socklib_recvall (rmi, sock, buf, MAX_PLS_LEN, rmi->prefs->timeout);
     if (bytes < SR_SUCCESS) return bytes;
     if (bytes == 0 || bytes == MAX_PLS_LEN) {
 	debug_printf("Failed in getting PLS (%d bytes)\n", bytes);
@@ -761,11 +771,10 @@ http_get_m3u (RIP_MANAGER_INFO* rmi, HSOCKET *sock, SR_HTTP_HEADER *info)
 {
     int bytes;
     char buf[MAX_M3U_LEN];
-    const int timeout = 30;
     char* p;
 
     debug_printf ("Reading m3u\n");
-    bytes = socklib_recvall (rmi, sock, buf, MAX_M3U_LEN, timeout);
+    bytes = socklib_recvall (rmi, sock, buf, MAX_M3U_LEN, rmi->prefs->timeout);
     if (bytes < SR_SUCCESS) return bytes;
     if (bytes == 0 || bytes == MAX_M3U_LEN) {
 	debug_printf("Failed in getting M3U (%d bytes)\n", bytes);
