@@ -55,7 +55,14 @@ static Parse_Rule m_default_rule_list[] = {
       "[[:space:]]*-?[[:space:]]*mp3pro$",
       ""
     },
-    { PARSERULE_CMD_MATCH, 
+    { PARSERULE_CMD_MATCH,
+      PARSERULE_ICASE,
+      1, 2, 0, 0, 0,
+      0,
+      "^[[:space:]]*(.*?[^-[:space:]])[[:space:]]+-[[:space:]]+(.*)[[:space:]]*$",
+      ""
+    },
+    { PARSERULE_CMD_MATCH,
       PARSERULE_ICASE,
       1, 2, 0, 0, 0,
       0,
@@ -379,7 +386,7 @@ init_metadata_parser (RIP_MANAGER_INFO* rmi, char* rules_file)
 
 	/* Compile the rule */
 	debug_printf ("Compiling the rule\n");
-	mstring_from_string (rmi, w_match_buf, MAX_RULE_SIZE, match_buf, 
+	gstring_from_string (rmi, w_match_buf, MAX_RULE_SIZE, match_buf, 
 			     CODESET_UTF8);
 	if (!compile_rule(&rmi->parse_rules[ri], w_match_buf)) {
 	    printf ("Warning: malformed regular expression:\n%s\n", 
@@ -394,7 +401,7 @@ init_metadata_parser (RIP_MANAGER_INFO* rmi, char* rules_file)
 	debug_printf ("Copying rule string (2)\n");
 	if (rmi->parse_rules[ri].cmd == PARSERULE_CMD_SUBST) {
 	    debug_printf ("Copying rule string (3)\n");
-	    mstring_from_string (rmi, w_subst_buf, MAX_RULE_SIZE, subst_buf, 
+	    gstring_from_string (rmi, w_subst_buf, MAX_RULE_SIZE, subst_buf, 
 				 CODESET_UTF8);
 	    debug_printf ("Copying rule string (4)\n");
 	    rmi->parse_rules[ri].subst = mstrdup(w_subst_buf);
@@ -428,7 +435,7 @@ compose_metadata (RIP_MANAGER_INFO* rmi, TRACK_INFO* ti)
 	debug_printf ("No track info when composing relay metadata\n");
     }
     debug_printf ("Converting relay string to char\n");
-    num_bytes = string_from_mstring (rmi, &ti->composed_metadata[1], 
+    num_bytes = string_from_gstring (rmi, &ti->composed_metadata[1], 
 				     MAX_METADATA_LEN, 
 				     w_composed_metadata, 
 				     CODESET_RELAY);
@@ -453,22 +460,17 @@ parse_metadata (RIP_MANAGER_INFO* rmi, TRACK_INFO* ti)
     /* Has any m/.../x rule matched? */
     BOOL exclude_track_matched = FALSE;
 
-    ti->have_track_info = 0;
     ti->artist[0] = 0;
     ti->title[0] = 0;
     ti->album[0] = 0;
     ti->composed_metadata[0] = 0;
     ti->save_track = TRUE;
-    if (!ti->raw_metadata[0]) {
-	debug_printf ("Couldn't parse because no meta data\n");
-	return;
-    }
 
     /* Loop through rules, if we find a matching rule, then use it */
     /* For now, only default rules supported with ascii 
        regular expressions. */
     debug_printf ("Converting query string to wide\n");
-    mstring_from_string (rmi, query_string, MAX_TRACK_LEN, 
+    gstring_from_string (rmi, query_string, MAX_TRACK_LEN, 
 			 ti->raw_metadata, CODESET_METADATA);
     for (rulep = rmi->parse_rules; rulep->cmd; rulep++) {
 #if !defined (USE_GLIB_REGEX)
@@ -605,10 +607,13 @@ parse_metadata (RIP_MANAGER_INFO* rmi, TRACK_INFO* ti)
 		continue;
 	    }
 	    tmp = g_strndup (query_string, start_pos);
-	    subst_string = g_strconcat (tmp, rulep->subst, 
-					&query_string[end_pos+1],
+	    tmp[start_pos] = 0;
+	    subst_string = g_strconcat (tmp,
+					rulep->subst, 
+					&tmp[end_pos],
 					NULL);
 	    g_free (tmp);
+	    g_match_info_free (match_info);
 	    mstrncpy (query_string, subst_string, MAX_TRACK_LEN);
 #else
 	    mchar subst_string[MAX_TRACK_LEN];
