@@ -67,7 +67,6 @@ static error_code relaylib_start_threads (RIP_MANAGER_INFO* rmi);
 
 #define BUFSIZE (1024)
 
-#define HTTP_HEADER_TIMEOUT 2
 #define HTTP_HEADER_DELIM "\n"
 #define ICY_METADATA_TAG "Icy-MetaData:"
 
@@ -125,9 +124,9 @@ header_receive (int sock, int *icy_metadata)
 	// that lacks CRLF delimiter
 	FD_ZERO(&fds);
         FD_SET(sock, &fds);
-        tv.tv_sec = HTTP_HEADER_TIMEOUT;
+        tv.tv_sec = 2;
         tv.tv_usec = 0;
-        r = select(sock + 1, &fds, NULL, NULL, &tv);
+        r = select (sock + 1, &fds, NULL, NULL, &tv);
         if (r != 1) {
 	    debug_printf ("header_receive: could not select\n");
 	    break;
@@ -487,7 +486,7 @@ thread_accept (void* arg)
             tv.tv_usec = 0;
 	    debug_printf("thread_accept:calling select()\n");
             ret = select (rli->m_listensock + 1, &fds, NULL, NULL, &tv);
-	    debug_printf("thread_accept:select() returned\n");
+	    debug_printf("thread_accept:select() returned %d\n", ret);
             if (ret == 1) {
                 unsigned long num_connected;
                 /* If connections are full, do nothing.  Note that 
