@@ -122,6 +122,7 @@ rip_manager_start (RIP_MANAGER_INFO **rmip,
 
     rmi->status_callback = status_callback;
     rmi->bytes_ripped = 0;
+    rmi->megabytes_ripped = 0;
     rmi->write_data = 1;
 
     /* Initialize the parsing rules */
@@ -219,7 +220,7 @@ compose_console_string (RIP_MANAGER_INFO *rmi, TRACK_INFO* ti)
     mchar console_string[SR_MAX_PATH];
     msnprintf (console_string, SR_MAX_PATH, m_S m_(" - ") m_S, 
 	       ti->artist, ti->title);
-    string_from_mstring (rmi, rmi->filename, SR_MAX_PATH, console_string,
+    string_from_gstring (rmi, rmi->filename, SR_MAX_PATH, console_string,
 			 CODESET_LOCALE);
 }
 
@@ -278,7 +279,7 @@ rip_manager_end_track (RIP_MANAGER_INFO* rmi, TRACK_INFO* ti)
     }
     post_status(rmi, 0);
 
-    string_from_mstring (rmi, fullpath, SR_MAX_PATH, mfullpath, CODESET_FILESYS);
+    string_from_gstring (rmi, fullpath, SR_MAX_PATH, mfullpath, CODESET_FILESYS);
     rmi->status_callback (rmi, RM_TRACK_DONE, (void*)fullpath);
 
     return SR_SUCCESS;
@@ -301,6 +302,10 @@ rip_manager_put_data (RIP_MANAGER_INFO *rmi, char *buf, int size)
 
     rmi->filesize += size;	/* This is used by the GUI */
     rmi->bytes_ripped += size;	/* This is used to determine when to quit */
+    while (rmi->bytes_ripped >= 1048576) {
+	rmi->bytes_ripped -= 1048576;
+	rmi->megabytes_ripped++;
+    }
 
     return SR_SUCCESS;
 }
@@ -372,8 +377,8 @@ ripthread (void *thread_arg)
 	if (!rmi->started) {
 	    break;
 	}
-	else if (rmi->bytes_ripped/1000000 >= (rmi->prefs->maxMB_rip_size) &&
-		GET_CHECK_MAX_BYTES (rmi->prefs->flags)) {
+	else if (rmi->megabytes_ripped >= rmi->prefs->maxMB_rip_size 
+		 && GET_CHECK_MAX_BYTES (rmi->prefs->flags)) {
 	    /* GCS Aug 23, 2003: bytes_ripped can still overflow */
 	    socklib_close (&rmi->stream_sock);
 	    destroy_subsystems (rmi);
@@ -490,6 +495,7 @@ start_ripping (RIP_MANAGER_INFO* rmi)
 	char const *env_http_proxy = getenv ("http_proxy");
 	if (env_http_proxy) {
 	    pproxy = env_http_proxy;
+	    debug_printf ("Getting proxy from $http_proxy: %s\n", pproxy);
 	}
     }
 
