@@ -77,15 +77,6 @@ typedef struct ID3V1st
         char    genre;
 } ID3V1Tag;
 
-#if defined (commentout)
-typedef struct ID3V2headst {
-	char	tag[3];
-	int	version;
-	char	flags;
-	int	size;
-} ID3V2head;
-#endif
-
 typedef struct ID3V2framest {
 	char	id[4];
 	int	size;
@@ -161,7 +152,7 @@ is_track_changed (RIP_MANAGER_INFO* rmi)
 }
 
 static void
-format_track_info (TRACK_INFO* ti, char* tag)
+debug_track_info (TRACK_INFO* ti, char* tag)
 {
     debug_mprintf (m_("----- TRACK_INFO ") m_s m_("\n")
 		   m_("HAVETI: %d\n")
@@ -238,7 +229,7 @@ ripstream_rip_ogg (RIP_MANAGER_INFO* rmi)
 
     /* get the data from the stream */
     debug_printf ("RIPSTREAM_RIP_OGG: top of loop\n");
-    ret = get_stream_data(rmi, rmi->getbuffer, rmi->current_track.raw_metadata);
+    ret = get_stream_data (rmi, rmi->getbuffer, rmi->current_track.raw_metadata);
     if (ret != SR_SUCCESS) {
 	debug_printf("get_stream_data bad return code: %d\n", ret);
 	return ret;
@@ -254,14 +245,15 @@ ripstream_rip_ogg (RIP_MANAGER_INFO* rmi)
 			  GET_MAKE_RELAY(rmi->prefs->flags),
 			  rmi->getbuffer_size, rmi->cbuf2_size);
 	if (ret != SR_SUCCESS) return ret;
-	rmi->ogg_have_track = 0;
+	rmi->ogg_track_state = 0;
 	/* Warm up the ogg decoding routines */
 	rip_ogg_init (rmi);
 	/* Done! */
 	rmi->ripstream_first_time_through = 0;
     }
 
-    /* Copy the data into cbuffer */
+    /* Copy the data into cbuffer.  This calls rip_ogg_process_chunk,
+       which sets TRACK_INFO. */
     clear_track_info (&rmi->current_track);
     ret = cbuf2_insert_chunk (rmi, &rmi->cbuf2, 
 			      rmi->getbuffer, rmi->getbuffer_size,
@@ -278,6 +270,8 @@ ripstream_rip_ogg (RIP_MANAGER_INFO* rmi)
         return ret;
     }
 
+
+#if defined (commentout)
     /* If we have unwritten pages for the current track, write them */
     if (rmi->ogg_have_track) {
 	do {
@@ -289,10 +283,11 @@ ripstream_rip_ogg (RIP_MANAGER_INFO* rmi)
 				       &amt_filled, &got_eos);
 	    debug_printf ("^^^ogg_peek: %d %d\n", amt_filled, got_eos);
 	    if (ret != SR_SUCCESS) {
-		debug_printf ("cbuf2_ogg_peek_song: %d\n",ret);
+		debug_printf ("cbuf2_ogg_peek_song: %d\n", ret);
 		return ret;
 	    }
 	    if (amt_filled == 0) {
+		/* No more pages */
 		break;
 	    }
 	    ret = rip_manager_put_data (rmi, rmi->getbuffer, amt_filled);
@@ -301,14 +296,14 @@ ripstream_rip_ogg (RIP_MANAGER_INFO* rmi)
 		return ret;
 	    }
 	    if (got_eos) {
-		end_track_ogg (rmi, &rmi->old_track);
+		//end_track_ogg (rmi, &rmi->old_track);
 		rmi->ogg_have_track = 0;
-		break;
+		//break;
 	    }
 	} while (1);
     }
 
-    format_track_info (&rmi->current_track, "current");
+    debug_track_info (&rmi->current_track, "current");
 
     /* If we got a new track, then start a new file */
     if (rmi->current_track.have_track_info) {
@@ -322,6 +317,60 @@ ripstream_rip_ogg (RIP_MANAGER_INFO* rmi)
 
 	rmi->ogg_have_track = 1;
     }
+#endif
+
+    debug_printf ("ogg_track_state[a] = %d\n", rmi->ogg_track_state);
+
+    /* If we have unwritten pages for the current track, write them */
+    if (rmi->ogg_track_state == 1) {
+	do {
+	    error_code ret;
+	    unsigned long amt_filled;
+	    int got_eos;
+
+	    ret = cbuf2_ogg_peek_song (&rmi->cbuf2, rmi->getbuffer, 
+				       rmi->getbuffer_size,
+				       &amt_filled, &got_eos);
+	    debug_printf ("^^^ogg_peek: %d %d\n", amt_filled, got_eos);
+	    if (ret != SR_SUCCESS) {
+		debug_printf ("cbuf2_ogg_peek_song: %d\n", ret);
+		return ret;
+	    }
+	    if (amt_filled == 0) {
+		/* No more pages */
+		break;
+	    }
+	    ret = rip_manager_put_data (rmi, rmi->getbuffer, amt_filled);
+	    if (ret != SR_SUCCESS) {
+		debug_printf ("rip_manager_put_data(#1): %d\n",ret);
+		return ret;
+	    }
+	    if (got_eos) {
+		rmi->ogg_track_state = 2;
+		break;
+	    }
+
+	} while (1);
+    }
+
+    debug_printf ("ogg_track_state[b] = %d\n", rmi->ogg_track_state);
+    debug_track_info (&rmi->current_track, "current");
+
+    /* If we got a new track, then (maybe) start a new file */
+    if (rmi->current_track.have_track_info) {
+	if (is_track_changed (rmi)) {
+	    if (rmi->ogg_track_state == 2) {
+		end_track_ogg (rmi, &rmi->old_track);
+	    }
+	    ret = rip_manager_start_track (rmi, &rmi->current_track);
+	    if (ret != SR_SUCCESS) {
+		debug_printf ("rip_manager_start_track failed(#1): %d\n",ret);
+		return ret;
+	    }
+	    copy_track_info (&rmi->old_track, &rmi->current_track);
+	}
+	rmi->ogg_track_state = 1;
+    }
 
     /* If buffer almost full, advance the buffer */
     if (cbuf2_get_free(&rmi->cbuf2) < rmi->getbuffer_size) {
@@ -394,7 +443,7 @@ ripstream_rip_mp3 (RIP_MANAGER_INFO* rmi)
 	read_external (rmi, rmi->ep, &rmi->current_track);
     } else {
 	/* Otherwise, apply parse rules to raw metadata */
-	if (rmi->current_track.raw_metadata[0]) {
+	if (rmi->current_track.have_track_info) {
 	    parse_metadata (rmi, &rmi->current_track);
 	} else {
 	    clear_track_info (&rmi->current_track);
@@ -460,9 +509,9 @@ ripstream_rip_mp3 (RIP_MANAGER_INFO* rmi)
 	}
     }
 
-    format_track_info (&rmi->old_track, "old");
-    format_track_info (&rmi->new_track, "new");
-    format_track_info (&rmi->current_track, "current");
+    debug_track_info (&rmi->old_track, "old");
+    debug_track_info (&rmi->new_track, "new");
+    debug_track_info (&rmi->current_track, "current");
 
     if (rmi->find_silence == 0) {
 	/* Find separation point */
@@ -543,8 +592,9 @@ find_sep (RIP_MANAGER_INFO* rmi, u_long* pos1, u_long* pos2)
 	return SR_ERROR_REQUIRED_WINDOW_EMPTY;
     }
 
-    debug_printf ("search window (bytes): %d,%d,%d\n", rw_start, rw_end,
-		  rmi->cbuf2.item_count);
+    debug_printf ("search window (bytes): [%d,%d] within %d\n", 
+		    rw_start, rw_end,
+		    rmi->cbuf2.item_count);
 
     if (rmi->http_info.content_type != CONTENT_TYPE_MP3) {
 	sw_sil = (rw_end + rw_start) / 2;
@@ -621,19 +671,19 @@ end_track_mp3 (RIP_MANAGER_INFO* rmi, u_long pos1, u_long pos2, TRACK_INFO* ti)
 
     /* Add id3v1 if requested */
     if (GET_ADD_ID3V1(rmi->prefs->flags)) {
-	ID3V1Tag id3;
-	memset (&id3, '\000',sizeof(id3));
-	strncpy (id3.tag, "TAG", strlen("TAG"));
-	string_from_mstring (rmi, id3.artist, sizeof(id3.artist), 
+	ID3V1Tag id3v1;
+	memset (&id3v1, '\000',sizeof(id3v1));
+	strncpy (id3v1.tag, "TAG", strlen("TAG"));
+	string_from_gstring (rmi, id3v1.artist, sizeof(id3v1.artist),
 			     ti->artist, CODESET_ID3);
-	string_from_mstring (rmi, id3.songtitle, sizeof(id3.songtitle), 
+	string_from_gstring (rmi, id3v1.songtitle, sizeof(id3v1.songtitle),
 			     ti->title, CODESET_ID3);
-	string_from_mstring (rmi, id3.album, sizeof(id3.album),
+	string_from_gstring (rmi, id3v1.album, sizeof(id3v1.album),
 			     ti->album, CODESET_ID3);
-	string_from_mstring (rmi, id3.year, sizeof(id3.year),
+	string_from_gstring (rmi, id3v1.year, sizeof(id3v1.year),
 			     ti->year, CODESET_ID3);
-	id3.genre = (char) 0xFF; // see http://www.id3.org/id3v2.3.0.html#secA
-	ret = rip_manager_put_data (rmi, (char *)&id3, sizeof(id3));
+	id3v1.genre = (char) 0xFF; // see http://www.id3.org/id3v2.3.0.html#secA
+	ret = rip_manager_put_data (rmi, (char *)&id3v1, sizeof(id3v1));
 	if (ret != SR_SUCCESS) {
 	    goto BAIL;
 	}
@@ -641,9 +691,8 @@ end_track_mp3 (RIP_MANAGER_INFO* rmi, u_long pos1, u_long pos2, TRACK_INFO* ti)
 
     /* Only save this track if we've skipped over enough cruft 
        at the beginning of the stream */
-    debug_printf("Current track number %d (dropcount is %d)\n", 
-		 rmi->track_count, 
-		 rmi->prefs->dropcount);
+    debug_printf ("Current track number %d (skipping if less than %d)\n", 
+		  rmi->track_count, rmi->prefs->dropcount);
     if (rmi->track_count >= rmi->prefs->dropcount)
 	if ((ret = rip_manager_end_track (rmi, ti)) != SR_SUCCESS)
 	    goto BAIL;
@@ -673,7 +722,7 @@ write_id3v2_frame(RIP_MANAGER_INFO* rmi, char* tag_name, mchar* data,
     memset(&id3v2frame, '\000', sizeof(id3v2frame));
     strncpy(id3v2frame.id, tag_name, 4);
     id3v2frame.pad[2] = charset;
-    rc = string_from_mstring (rmi, bigbuf, HEADER_SIZE, data, CODESET_ID3);
+    rc = string_from_gstring (rmi, bigbuf, HEADER_SIZE, data, CODESET_ID3);
     framesize = htonl (rc+1);
     ret = rip_manager_put_data (rmi, (char *)&(id3v2frame.id), 4);
     if (ret != SR_SUCCESS) return ret;
@@ -744,16 +793,17 @@ start_track_mp3 (RIP_MANAGER_INFO* rmi, TRACK_INFO* ti)
 
         /* Encoded by */
         ret = write_id3v2_frame(rmi, "TENC",
-				m_("Ripped with Streamripper"), 0, &sent);
+				m_("Ripped with Streamripper"), 
+				id3_charset, &sent);
 	
         /* Album */
-        ret = write_id3v2_frame(rmi, "TALB", ti->album, 0, &sent);
+        ret = write_id3v2_frame(rmi, "TALB", ti->album, id3_charset, &sent);
 
         /* Track */
-        ret = write_id3v2_frame(rmi, "TRCK", ti->track_a, 0, &sent);
+        ret = write_id3v2_frame(rmi, "TRCK", ti->track_a, id3_charset, &sent);
 
         /* Year */
-        ret = write_id3v2_frame(rmi, "TYER", ti->year, 0, &sent);
+        ret = write_id3v2_frame(rmi, "TYER", ti->year, id3_charset, &sent);
 
 	/* Zero out padding */
 	memset (bigbuf, '\000', sizeof(bigbuf));
@@ -777,9 +827,9 @@ static error_code
 end_track_ogg (RIP_MANAGER_INFO* rmi, TRACK_INFO* ti)
 {
     error_code ret;
-    debug_printf ("Current track number %d (skipping if %d or less)\n", 
+    debug_printf ("Current track number %d (skipping if less than %d)\n", 
 		  rmi->track_count, rmi->prefs->dropcount);
-    if (rmi->track_count > rmi->prefs->dropcount) {
+    if (rmi->track_count >= rmi->prefs->dropcount) {
 	ret = rip_manager_end_track (rmi, ti);
     } else {
 	ret = SR_SUCCESS;
@@ -839,12 +889,13 @@ bytes_to_secs (unsigned int bytes, int bitrate)
    we also buffer up to the latest point that can go into the 
    next song.  This is called the "required window."
 
-   The entire required window is decoded, even though 
-   we don't need the volume.  We simply mark the frame boundaries
-   so we don't chop any frames.
+   The "required window" is part that is decoded, even though 
+   we don't need volume data for all of it.  We simply mark the 
+   frame boundaries so we don't chop any frames.
 
-   The circular buffer is a bit bigger than the required window, 
-   because it contains an integer number of blocks which fall 
+   The circular buffer is a bit bigger than the required window. 
+   This includes all of the stuff which cannot be flushed out of 
+   the cbuf, because cbuf is flushed in blocks.
 
    Some abbreviations:
      mic      meta inf change
@@ -870,11 +921,14 @@ bytes_to_secs (unsigned int bytes, int bitrate)
 
          |--------------------------------|       required window
 
+                        |---------|               minimum rw (1 meta int, 
+                                                  includes sw, need not 
+                                                  be aligned to metadata)
+
     |---------------------------------------|     cbuf
 
-
-                   |<-------------+               mic_to_sw_start
-                                  +---->|         mic_to_sw_end
+                   |<-------------+               mic_to_sw_start (usu neg)
+                                  +---->|         mic_to_sw_end   (usu pos)
          |<-----------------------+               mic_to_rw_start
                                   +------>|       mic_to_rw_end
     |<----------------------------+               mic_to_cb_start
@@ -891,11 +945,19 @@ compute_cbuf2_size (RIP_MANAGER_INFO* rmi,
     long mi_to_mic;
     long prepad, postpad;
     long offset;
+    long rw_len;
     long mic_to_sw_start, mic_to_sw_end;
     long mic_to_rw_start, mic_to_rw_end;
     long mic_to_cb_start, mic_to_cb_end;
+    int xs_silence_length;
+    int xs_search_window_1;
+    int xs_search_window_2;
+    int xs_offset;
+    int xs_padding_1;
+    int xs_padding_2;
 
     debug_printf ("---------------------------------------------------\n");
+    debug_printf ("xs: %d\n", sp_opt->xs);
     debug_printf ("xs_search_window: %d,%d\n",
 		  sp_opt->xs_search_window_1,sp_opt->xs_search_window_2);
     debug_printf ("xs_silence_length: %d\n", sp_opt->xs_silence_length);
@@ -906,34 +968,52 @@ compute_cbuf2_size (RIP_MANAGER_INFO* rmi,
     debug_printf ("bitrate = %d, meta_inf = %d\n", bitrate, meta_interval);
     debug_printf ("---------------------------------------------------\n");
     
+    /* If xs-none, clear out the other xs options */
+    if (sp_opt->xs == 0){
+	xs_silence_length = 0;
+	xs_search_window_1 = 0;
+	xs_search_window_2 = 0;
+	xs_offset = 0;
+	xs_padding_1 = 0;
+	xs_padding_2 = 0;
+    } else {
+	xs_silence_length = sp_opt->xs_silence_length;
+	xs_search_window_1 = sp_opt->xs_search_window_1;
+	xs_search_window_2 = sp_opt->xs_search_window_2;
+	xs_offset = sp_opt->xs_offset;
+	xs_padding_1 = sp_opt->xs_padding_1;
+	xs_padding_2 = sp_opt->xs_padding_2;
+    }
+
+
     /* mi_to_mic is the "half of a meta-inf" from the meta inf 
        change to the previous (non-changed) meta inf */
     mi_to_mic = meta_interval / 2;
     debug_printf ("mi_to_mic: %d\n", mi_to_mic);
 
     /* compute the search window size (sws) */
-    sws = ms_to_bytes (sp_opt->xs_search_window_1, bitrate) 
-	    + ms_to_bytes (sp_opt->xs_search_window_2, bitrate);
+    sws = ms_to_bytes (xs_search_window_1, bitrate) 
+	    + ms_to_bytes (xs_search_window_2, bitrate);
     debug_printf ("sws: %d\n", sws);
 
     /* compute the silence length (sl) */
-    sl = ms_to_bytes (sp_opt->xs_silence_length, bitrate);
+    sl = ms_to_bytes (xs_silence_length, bitrate);
     debug_printf ("sl: %d\n", sl);
 
     /* compute padding */
-    prepad = ms_to_bytes (sp_opt->xs_padding_1, bitrate);
-    postpad = ms_to_bytes (sp_opt->xs_padding_2, bitrate);
+    prepad = ms_to_bytes (xs_padding_1, bitrate);
+    postpad = ms_to_bytes (xs_padding_2, bitrate);
     debug_printf ("padding: %d %d\n", prepad, postpad);
 
     /* compute offset */
-    offset = ms_to_bytes(sp_opt->xs_offset,bitrate);
+    offset = ms_to_bytes (xs_offset,bitrate);
     debug_printf ("offset: %d\n", offset);
 
     /* compute interval from mi to search window */
     mic_to_sw_start = - mi_to_mic + offset 
-	    - ms_to_bytes(sp_opt->xs_search_window_1,bitrate);
+	    - ms_to_bytes(xs_search_window_1,bitrate);
     mic_to_sw_end = - mi_to_mic + offset 
-	    + ms_to_bytes(sp_opt->xs_search_window_2,bitrate);
+	    + ms_to_bytes(xs_search_window_2,bitrate);
     debug_printf ("mic_to_sw_start: %d\n", mic_to_sw_start);
     debug_printf ("mic_to_sw_end: %d\n", mic_to_sw_end);
 
@@ -949,6 +1029,17 @@ compute_cbuf2_size (RIP_MANAGER_INFO* rmi,
     debug_printf ("mic_to_rw_start: %d\n", mic_to_rw_start);
     debug_printf ("mic_to_rw_end: %d\n", mic_to_rw_end);
 
+    /* if rw is not long enough, make it longer */
+    rw_len = mic_to_rw_end - mic_to_rw_start;
+    if (rw_len < meta_interval) {
+	long start_extra = (meta_interval - rw_len) / 2;
+	long end_extra = meta_interval - start_extra;
+	mic_to_rw_start -= start_extra;
+	mic_to_rw_end += end_extra;
+	debug_printf ("mic_to_rw_start (2): %d\n", mic_to_rw_start);
+	debug_printf ("mic_to_rw_end (2): %d\n", mic_to_rw_end);
+    }
+
     /* This code replaces the 3 cases (see OBSOLETE in gcs_notes.txt) */
     mic_to_cb_start = mic_to_rw_start;
     mic_to_cb_end = mic_to_rw_end;
@@ -976,7 +1067,7 @@ compute_cbuf2_size (RIP_MANAGER_INFO* rmi,
     rmi->mic_to_cb_end = mic_to_cb_end;
     rmi->rw_start_to_cb_end = mic_to_cb_end * meta_interval - mic_to_rw_start;
     rmi->rw_end_to_cb_end = mic_to_cb_end * meta_interval - mic_to_rw_end;
-    rmi->rw_start_to_sw_start = sp_opt->xs_padding_1 - sp_opt->xs_silence_length / 2;
+    rmi->rw_start_to_sw_start = xs_padding_1 - xs_silence_length / 2;
     if (rmi->rw_start_to_sw_start < 0) {
 	rmi->rw_start_to_sw_start = 0;
     }
@@ -1009,6 +1100,7 @@ get_stream_data (RIP_MANAGER_INFO* rmi, char *data_buf, char *track_buf)
     char newtrack[MAX_TRACK_LEN];
 
     *track_buf = 0;
+    rmi->current_track.have_track_info = 0;
     ret = ripstream_recvall (rmi, data_buf, rmi->getbuffer_size);
     if (ret <= 0)
 	return ret;
@@ -1025,26 +1117,18 @@ get_stream_data (RIP_MANAGER_INFO* rmi, char *data_buf, char *track_buf)
 	debug_printf ("Got invalid metadata: %d\n",c);
 	return SR_ERROR_INVALID_METADATA;
     } else if (c == 0) {
-	// around christmas time 2001 someone noticed that 1.8.7 shoutcast
-	// none-meta servers now just send a '0' if they have no meta data
-	// anyway, bassicly if the first meta capture is null then we assume
-	// that the stream does not have metadata
+	/* We didn't get any metadata this time. */
 	return SR_SUCCESS;
     } else {
+	/* We got metadata this time. */
 	ret = get_track_from_metadata (rmi, c * 16, newtrack);
 	if (ret != SR_SUCCESS) {
-	    debug_printf("get_trackname had a bad return %d", ret);
+	    debug_printf("get_trackname had a bad return %d\n", ret);
 	    return ret;
 	}
 
-	/* WolfFM is a station that does not stream meta-data, 
-	   but is in that format anyway.  StreamTitle='', so we need 
-	   to pretend this has no meta data. */
-	if (*newtrack == '\0') {
-	    return SR_SUCCESS;
-	}
-	/* This is the case where we got metadata. */
 	strncpy(track_buf, newtrack, MAX_TRACK_LEN);
+	rmi->current_track.have_track_info = 1;
     }
     return SR_SUCCESS;
 }
@@ -1055,6 +1139,11 @@ get_track_from_metadata (RIP_MANAGER_INFO* rmi, int size, char *newtrack)
     int i;
     int ret;
     char *namebuf;
+    char *p;
+    gchar *gnamebuf;
+
+    /* Default is no track info */
+    *newtrack = 0;
 
     if ((namebuf = malloc(size)) == NULL)
 	return SR_ERROR_CANT_ALLOC_MEMORY;
@@ -1074,20 +1163,47 @@ get_track_from_metadata (RIP_MANAGER_INFO* rmi, int size, char *newtrack)
     }
     debug_printf ("\n");
     for (i=0; i<size; i++) {
-	debug_printf ("%2c ",namebuf[i]);
+	if (namebuf[i] != 0) {
+	    debug_printf ("%2c ",namebuf[i]);
+	}
 	if (i % 20 == 19) {
 	    debug_printf ("\n");
 	}
     }
     debug_printf ("\n");
 
-    if(strstr(namebuf, "StreamTitle='") == NULL) {
-	free(namebuf);
-	return SR_ERROR_NO_TRACK_INFO;
-    }
-    subnstr_until(namebuf+strlen("StreamTitle='"), "';", newtrack, MAX_TRACK_LEN);
-    trim(newtrack);
+    /* Depending on version, Icecast/Shoutcast use one of the following.
+         StreamTitle='Title';StreamURL='URL';
+         StreamTitle='Title';
+       Limecast has no semicolon, and only example I've seen had no title.
+          StreamTitle=' '
+    */
 
+    /* GCS NOTE: This assumes ASCII-compatible charset for quote & semicolon.
+       Shoutcast protocol has no specification on this... */
+    if (!g_str_has_prefix (namebuf, "StreamTitle='")) {
+	free (namebuf);
+	return SR_SUCCESS;
+    }
+    gnamebuf = g_strdup (namebuf+strlen("StreamTitle='"));
     free(namebuf);
+
+    if ((p = strstr (gnamebuf, "';"))) {
+	*p = 0;
+    }
+    else if ((p = strrchr (gnamebuf, '\''))) {
+	*p = 0;
+    }
+    g_strstrip (gnamebuf);
+    debug_printf ("gnamebuf (stripped) = %s\n", gnamebuf);
+
+    if (strlen (gnamebuf) == 0) {
+	g_free (gnamebuf);
+	return SR_SUCCESS;
+    }
+
+    g_strlcpy (newtrack, gnamebuf, MAX_TRACK_LEN);
+    g_free (gnamebuf);
+
     return SR_SUCCESS;
 }
