@@ -196,9 +196,14 @@ typedef struct CODESET_OPTIONSst
 #define CODESET_METADATA      5
 #define CODESET_RELAY         6
 
-/* 
- * Wide character support
- */
+/* The Lstring is not null-terminated, and can belong to any locale */
+struct lstring {
+    gsize num_bytes;
+    gchar* data;
+};
+typedef struct lstring Lstring;
+
+/* The mchar is a legacy data structure, and should be removed */
 typedef gchar mchar;
 
 /* 
@@ -546,14 +551,19 @@ struct RIP_MANAGER_INFOst
     //void (*m_status_callback)(RIP_MANAGER_INFO* rmi, int message, void *data);
     RIP_MANAGER_CALLBACK status_callback;
 
-    /* Bytes ripped is stored to send to callback */
+    /* Bytes ripped is stored to send to callback, also used to decide 
+       when to stop based on bytes ripped. */
     u_long bytes_ripped;
+    u_long megabytes_ripped;
 
     /* Should we write a file for this track? */
     BOOL write_data;
 
     /* Used by ripstream ogg logic */
-    int ogg_have_track;
+    /* 0 : Track inactive, file closed */
+    /* 1 : Track active, file open */
+    /* 2 : Got eos, file open pending confirmed title change */
+    int ogg_track_state;
 
     /* Title & artist info */
     TRACK_INFO old_track;	    /* The track that's being ripped now */
