@@ -2,18 +2,13 @@
 #define __THREADLIB_H__
 
 #include "srtypes.h"
+#include "errors.h"
 #include "compat.h"
 
-typedef struct THREAD_HANDLEst
-{
-	THANDLE thread_handle;
-} THREAD_HANDLE;
-
-
-/*********************************************************************************
+/******************************************************************************
  * Public functions
- *********************************************************************************/
-extern error_code	threadlib_beginthread(THREAD_HANDLE *thread, void (*callback)(void *));
+ *****************************************************************************/
+error_code threadlib_beginthread (THREAD_HANDLE *thread, void (*callback)(void *), void* arg);
 extern BOOL		threadlib_isrunning(THREAD_HANDLE *thread);
 extern void		threadlib_waitforclose(THREAD_HANDLE *thread);
 extern void		threadlib_endthread(THREAD_HANDLE *thread);
